lilypondfiletools.LayoutBlock
=============================

.. inheritance-diagram:: abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.LayoutBlock
   :private-bases:

.. autoclass:: abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.LayoutBlock

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.LayoutBlock.context_blocks

.. autoattribute:: abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.LayoutBlock.contexts

.. autoattribute:: abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.LayoutBlock.format

   .. note:: Inherited from :py:class:`lilypondfiletools._AttributedBlock <abjad.tools.lilypondfiletools._AttributedBlock._AttributedBlock._AttributedBlock>`

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.LayoutBlock.is_formatted_when_empty

   .. note:: Inherited from :py:class:`lilypondfiletools._AttributedBlock <abjad.tools.lilypondfiletools._AttributedBlock._AttributedBlock._AttributedBlock>`

Special Methods
---------------

.. automethod:: abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.LayoutBlock.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.LayoutBlock.__hash__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.LayoutBlock.__repr__

   .. note:: Inherited from :py:class:`lilypondfiletools._AttributedBlock <abjad.tools.lilypondfiletools._AttributedBlock._AttributedBlock._AttributedBlock>`

.. automethod:: abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.LayoutBlock.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.LayoutBlock.__str__

   .. note:: Inherited from `__builtin__.object`
